##  How to Model REST APIs
You can follow the recommended practice to model REST APIs using interfaces.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749ee8d7a4410149718be159340d505_LowRes.png)
Here, you can see how the data flows between Microsoft Power BI and SAP LeanIX through the REST API.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275719697a441014b5efef3c00a627cb_LowRes.png)
Using the interface circle map with the filter on the API, you can apply the same view to your API as you did to your interfaces.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27551a247a4410149f53f4dec8154781_LowRes.png)
